@@ -1,7 +1,7 @@
 /*
  *  Simple library to detect and validate SSN and Credit Card numbers.
  *
- *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2020 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Martin Roesch <roesch@sourcefire.com>
@@ -176,6 +176,7 @@ int dlp_is_valid_cc(const unsigned char *buffer, size_t length)
     int mult   = 0;
     int sum    = 0;
     size_t i   = 0;
+    ssize_t j  = 0;
     int val    = 0;
     int digits = 0;
     char cc_digits[20];
@@ -232,9 +233,11 @@ int dlp_is_valid_cc(const unsigned char *buffer, size_t length)
     if (digits < 13 || (i < length && isdigit(buffer[i])))
         return 0;
 
+    j = (ssize_t)i;
+
     //figure out luhn digits
-    for (i = digits - 1; i >= 0; i--) {
-        val = cc_digits[i] - '0';
+    for (j = digits - 1; j >= 0; j--) {
+        val = cc_digits[j] - '0';
         if (mult) {
             if ((val *= 2) > 9) val -= 9;
         }
