@@ -1,10 +1,10 @@
 /*
- *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2020 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Trog
- * 
- *  Summary: Normalise HTML text. Decode MS Script Encoder protection. 
+ *
+ *  Summary: Normalise HTML text. Decode MS Script Encoder protection.
  *           The ScrEnc decoder was initially based upon an analysis by Andreas Marx.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,7 @@
 #ifndef __HTMLNORM_H
 #define __HTMLNORM_H
 
-typedef struct tag_arguments_tag
-{
+typedef struct tag_arguments_tag {
     int count;
     int scanContents;
     unsigned char **tag;
@@ -34,8 +33,7 @@ typedef struct tag_arguments_tag
     unsigned char **contents;
 } tag_arguments_t;
 
-typedef struct m_area_tag
-{
+typedef struct m_area_tag {
     unsigned char *buffer;
     off_t length;
     off_t offset;
