@@ -1,7 +1,7 @@
 /*
  *  Unit tests for HTML normalizer;
  *
- *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2020 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2008-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -39,7 +39,7 @@ static void htmlnorm_setup(void)
     cl_init(CL_INIT_DEFAULT);
     dconf_setup();
     dir = cli_gentemp(NULL);
-    fail_unless(!!dir, "cli_gentemp failed");
+    ck_assert_msg(!!dir, "cli_gentemp failed");
 }
 
 static void htmlnorm_teardown(void)
@@ -64,8 +64,6 @@ static struct test {
     {"input/htmlnorm_test.html", "test.nocomment.ref", "test.notags.ref", NULL},
     {"input/htmlnorm_urls.html", "urls.nocomment.ref", "urls.notags.ref", NULL}};
 
-#ifdef CHECK_HAVE_LOOPS
-
 static void check_dir(const char *dire, const struct test *test)
 {
     char filename[4096];
@@ -74,7 +72,7 @@ static void check_dir(const char *dire, const struct test *test)
     if (test->nocommentref) {
         snprintf(filename, sizeof(filename), "%s/nocomment.html", dire);
         fd = open(filename, O_RDONLY);
-        fail_unless(fd > 0, "unable to open: %s", filename);
+        ck_assert_msg(fd > 0, "unable to open: %s", filename);
         reffd = open_testfile(test->nocommentref);
 
         diff_files(fd, reffd);
@@ -85,7 +83,7 @@ static void check_dir(const char *dire, const struct test *test)
     if (test->notagsref) {
         snprintf(filename, sizeof(filename), "%s/notags.html", dire);
         fd = open(filename, O_RDONLY);
-        fail_unless(fd > 0, "unable to open: %s", filename);
+        ck_assert_msg(fd > 0, "unable to open: %s", filename);
         reffd = open_testfile(test->notagsref);
 
         diff_files(fd, reffd);
@@ -96,7 +94,7 @@ static void check_dir(const char *dire, const struct test *test)
     if (test->jsref) {
         snprintf(filename, sizeof(filename), "%s/javascript", dire);
         fd = open(filename, O_RDONLY);
-        fail_unless(fd > 0, "unable to open: %s", filename);
+        ck_assert_msg(fd > 0, "unable to open: %s", filename);
         reffd = open_testfile(test->jsref);
 
         diff_files(fd, reffd);
@@ -115,30 +113,30 @@ START_TEST(test_htmlnorm_api)
     memset(&hrefs, 0, sizeof(hrefs));
 
     fd = open_testfile(tests[_i].input);
-    fail_unless(fd > 0, "open_testfile failed");
+    ck_assert_msg(fd > 0, "open_testfile failed");
 
     map = fmap(fd, 0, 0);
-    fail_unless(!!map, "fmap failed");
+    ck_assert_msg(!!map, "fmap failed");
 
-    fail_unless(mkdir(dir, 0700) == 0, "mkdir failed");
-    fail_unless(html_normalise_map(map, dir, NULL, dconf) == 1, "html_normalise_map failed");
+    ck_assert_msg(mkdir(dir, 0700) == 0, "mkdir failed");
+    ck_assert_msg(html_normalise_map(map, dir, NULL, dconf) == 1, "html_normalise_map failed");
     check_dir(dir, &tests[_i]);
-    fail_unless(cli_rmdirs(dir) == 0, "rmdirs failed");
+    ck_assert_msg(cli_rmdirs(dir) == 0, "rmdirs failed");
 
-    fail_unless(mkdir(dir, 0700) == 0, "mkdir failed");
-    fail_unless(html_normalise_map(map, dir, NULL, NULL) == 1, "html_normalise_map failed");
-    fail_unless(cli_rmdirs(dir) == 0, "rmdirs failed");
+    ck_assert_msg(mkdir(dir, 0700) == 0, "mkdir failed");
+    ck_assert_msg(html_normalise_map(map, dir, NULL, NULL) == 1, "html_normalise_map failed");
+    ck_assert_msg(cli_rmdirs(dir) == 0, "rmdirs failed");
 
-    fail_unless(mkdir(dir, 0700) == 0, "mkdir failed");
-    fail_unless(html_normalise_map(map, dir, &hrefs, dconf) == 1, "html_normalise_map failed");
-    fail_unless(cli_rmdirs(dir) == 0, "rmdirs failed");
+    ck_assert_msg(mkdir(dir, 0700) == 0, "mkdir failed");
+    ck_assert_msg(html_normalise_map(map, dir, &hrefs, dconf) == 1, "html_normalise_map failed");
+    ck_assert_msg(cli_rmdirs(dir) == 0, "rmdirs failed");
     html_tag_arg_free(&hrefs);
 
     memset(&hrefs, 0, sizeof(hrefs));
     hrefs.scanContents = 1;
-    fail_unless(mkdir(dir, 0700) == 0, "mkdir failed");
-    fail_unless(html_normalise_map(map, dir, &hrefs, dconf) == 1, "html_normalise_map failed");
-    fail_unless(cli_rmdirs(dir) == 0, "rmdirs failed");
+    ck_assert_msg(mkdir(dir, 0700) == 0, "mkdir failed");
+    ck_assert_msg(html_normalise_map(map, dir, &hrefs, dconf) == 1, "html_normalise_map failed");
+    ck_assert_msg(cli_rmdirs(dir) == 0, "rmdirs failed");
     html_tag_arg_free(&hrefs);
 
     funmap(map);
@@ -146,19 +144,18 @@ START_TEST(test_htmlnorm_api)
     close(fd);
 }
 END_TEST
-#endif
 
 START_TEST(test_screnc_nullterminate)
 {
     int fd = open_testfile("input/screnc_test");
     fmap_t *map;
 
-    fail_unless(mkdir(dir, 0700) == 0, "mkdir failed");
+    ck_assert_msg(mkdir(dir, 0700) == 0, "mkdir failed");
     map = fmap(fd, 0, 0);
-    fail_unless(!!map, "fmap failed");
-    fail_unless(html_screnc_decode(map, dir) == 1, "html_screnc_decode failed");
+    ck_assert_msg(!!map, "fmap failed");
+    ck_assert_msg(html_screnc_decode(map, dir) == 1, "html_screnc_decode failed");
     funmap(map);
-    fail_unless(cli_rmdirs(dir) == 0, "rmdirs failed");
+    ck_assert_msg(cli_rmdirs(dir) == 0, "rmdirs failed");
     close(fd);
 }
 END_TEST
@@ -170,9 +167,9 @@ Suite *test_htmlnorm_suite(void)
 
     tc_htmlnorm_api = tcase_create("htmlnorm api");
     suite_add_tcase(s, tc_htmlnorm_api);
-#ifdef CHECK_HAVE_LOOPS
+
     tcase_add_loop_test(tc_htmlnorm_api, test_htmlnorm_api, 0, sizeof(tests) / sizeof(tests[0]));
-#endif
+
     tcase_add_unchecked_fixture(tc_htmlnorm_api,
                                 htmlnorm_setup, htmlnorm_teardown);
     tcase_add_test(tc_htmlnorm_api, test_screnc_nullterminate);
